@@ -28,12 +28,12 @@ class BitButton : public QAbstractButton {
 	Q_OBJECT
 
 public:
-	explicit BitButton(QWidget *parent = 0);
+    explicit BitButton(QWidget *parent = nullptr);
 	bool isOn() const;
 	void setOn(bool value);
 
 protected:
-	void paintEvent(QPaintEvent *event) Q_DECL_OVERRIDE;
+	void paintEvent(QPaintEvent *event) override;
 
 private:
 	bool on_;
