@@ -46,6 +46,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <KToolBar>
 #include <kxmlguifactory.h>
 #include <Kdelibs4ConfigMigrator>
+#include <KCrash>
 
 #include "kcalc_bitset.h"
 #include "kcalc_const_menu.h"
@@ -68,8 +69,8 @@ KCalculator::KCalculator(QWidget *parent) :
 		shift_mode_(false),
 		hyp_mode_(false),
 		memory_num_(0.0),
-		constants_menu_(0),
-		constants_(0),
+        constants_menu_(nullptr),
+        constants_(nullptr),
 		core() {
 
 	// central widget to contain all the elements
@@ -97,14 +98,14 @@ KCalculator::KCalculator(QWidget *parent) :
 	base_choose_group_->addButton(decRadio, DecMode);
 	base_choose_group_->addButton(octRadio, OctMode);
 	base_choose_group_->addButton(binRadio, BinMode);
-	connect(base_choose_group_, static_cast<void (QButtonGroup::*)(int)>(&QButtonGroup::buttonClicked), this, &KCalculator::slotBaseSelected);
+	connect(base_choose_group_, QOverload<int>::of(&QButtonGroup::buttonClicked), this, &KCalculator::slotBaseSelected);
 
 	angle_choose_group_ =  new QButtonGroup(this);
 	angle_choose_group_->setExclusive(true);
 	angle_choose_group_->addButton(degRadio, DegMode);
 	angle_choose_group_->addButton(radRadio, RadMode);
 	angle_choose_group_->addButton(gradRadio, GradMode);
-	connect(angle_choose_group_, static_cast<void (QButtonGroup::*)(int)>(&QButtonGroup::buttonClicked), this, &KCalculator::slotAngleSelected);
+	connect(angle_choose_group_, QOverload<int>::of(&QButtonGroup::buttonClicked), this, &KCalculator::slotAngleSelected);
 
 	// additional menu setup
 	constants_menu_ = createConstantsMenu();
@@ -180,33 +181,33 @@ void KCalculator::setupMainActions() {
 	// mode menu
 	QActionGroup *modeGroup = new QActionGroup(this);
 
-	action_mode_simple_ = actionCollection()->add<KToggleAction>(QLatin1String("mode_simple"));
+	action_mode_simple_ = actionCollection()->add<KToggleAction>(QStringLiteral("mode_simple"));
 	action_mode_simple_->setActionGroup(modeGroup);
 	action_mode_simple_->setText(i18n("Simple Mode"));
 	connect(action_mode_simple_, &KToggleAction::toggled, this, &KCalculator::slotSetSimpleMode);
 
-	action_mode_science_ = actionCollection()->add<KToggleAction>(QLatin1String("mode_science"));
+	action_mode_science_ = actionCollection()->add<KToggleAction>(QStringLiteral("mode_science"));
 	action_mode_science_->setActionGroup(modeGroup);
 	action_mode_science_->setText(i18n("Science Mode"));
 	connect(action_mode_science_, &KToggleAction::toggled, this, &KCalculator::slotSetScienceMode);
 
-	action_mode_statistic_ = actionCollection()->add<KToggleAction>(QLatin1String("mode_statistics"));
+	action_mode_statistic_ = actionCollection()->add<KToggleAction>(QStringLiteral("mode_statistics"));
 	action_mode_statistic_->setActionGroup(modeGroup);
 	action_mode_statistic_->setText(i18n("Statistic Mode"));
 	connect(action_mode_statistic_, &KToggleAction::toggled, this, &KCalculator::slotSetStatisticMode);
 
-	action_mode_numeral_ = actionCollection()->add<KToggleAction>(QLatin1String("mode_numeral"));
+	action_mode_numeral_ = actionCollection()->add<KToggleAction>(QStringLiteral("mode_numeral"));
 	action_mode_numeral_->setActionGroup(modeGroup);
 	action_mode_numeral_->setText(i18n("Numeral System Mode"));
 	connect(action_mode_numeral_, &KToggleAction::toggled, this, &KCalculator::slotSetNumeralMode);
 
 	// settings menu
-	action_constants_show_ = actionCollection()->add<KToggleAction>(QLatin1String("show_constants"));
+	action_constants_show_ = actionCollection()->add<KToggleAction>(QStringLiteral("show_constants"));
 	action_constants_show_->setText(i18n("Constants &Buttons"));
 	action_constants_show_->setChecked(true);
 	connect(action_constants_show_, &KToggleAction::toggled, this, &KCalculator::slotConstantsShow);
 
-	action_bitset_show_ = actionCollection()->add<KToggleAction>(QLatin1String("show_bitset"));
+	action_bitset_show_ = actionCollection()->add<KToggleAction>(QStringLiteral("show_bitset"));
 	action_bitset_show_->setText(i18n("Show B&it Edit"));
 	action_bitset_show_->setChecked(true);
 	connect(action_bitset_show_, &KToggleAction::toggled, this, &KCalculator::slotBitsetshow);
@@ -242,7 +243,7 @@ KCalcStatusBar *KCalculator::statusBar() {
 void KCalculator::setupNumberKeys() {
 
     num_button_group_ = new QButtonGroup(this);
-    connect(num_button_group_, static_cast<void (QButtonGroup::*)(int)>(&QButtonGroup::buttonClicked), this, &KCalculator::slotNumberclicked);
+    connect(num_button_group_, QOverload<int>::of(&QButtonGroup::buttonClicked), this, &KCalculator::slotNumberclicked);
 
     num_button_group_->addButton(pb0, 0);
     num_button_group_->addButton(pb1, 1);
@@ -342,7 +343,7 @@ void KCalculator::setupRightKeypad() {
 void KCalculator::setupNumericKeypad() {
 
 	pbCube->addMode(ModeNormal, i18nc("Third power", "x<sup>3</sup>"), i18n("Third power"));
-	pbCube->addMode(ModeShift, QLatin1String("<sup>3</sup>&radic;x"), i18n("Cube root"));
+	pbCube->addMode(ModeShift, QStringLiteral("<sup>3</sup>&radic;x"), i18n("Cube root"));
 	connect(pbCube, &KCalcButton::clicked, this, &KCalculator::slotCubeclicked);
 	connect(this, &KCalculator::switchShowAccels, pbCube, &KCalcButton::slotSetAccelDisplayMode);
 	connect(this, &KCalculator::switchMode, pbCube, &KCalcButton::slotSetMode);
@@ -586,14 +587,14 @@ void KCalculator::setupMiscKeys() {
 	connect(pbReci, &KCalcButton::clicked, this, &KCalculator::slotReciclicked);
 
 	pbFactorial->addMode(ModeNormal, i18nc("Factorial", "x!"), i18n("Factorial"));
-	pbFactorial->addMode(ModeShift, QLatin1String("&#915;"), i18n("Gamma"));
+	pbFactorial->addMode(ModeShift, QStringLiteral("&#915;"), i18n("Gamma"));
 	pbFactorial->setShortcut(QKeySequence(Qt::Key_Exclam));
 	connect(this, &KCalculator::switchShowAccels, pbFactorial, &KCalcButton::slotSetAccelDisplayMode);
 	connect(this, &KCalculator::switchMode, pbFactorial, &KCalcButton::slotSetMode);
 	connect(pbFactorial, &KCalcButton::clicked, this, &KCalculator::slotFactorialclicked);
 
 	pbSquare->addMode(ModeNormal, i18nc("Square", "x<sup>2</sup>"), i18n("Square"));
-	pbSquare->addMode(ModeShift, QLatin1String("&radic;x"), i18n("Square root"));
+	pbSquare->addMode(ModeShift, QStringLiteral("&radic;x"), i18n("Square root"));
 	pbSquare->setShortcut(QKeySequence(Qt::Key_BracketLeft));
 	new QShortcut(Qt::Key_twosuperior, pbSquare, SLOT(animateClick()));
 	connect(this, &KCalculator::switchShowAccels, pbSquare, &KCalcButton::slotSetAccelDisplayMode);
@@ -676,8 +677,8 @@ void KCalculator::setupKeys() {
 //------------------------------------------------------------------------------
 void KCalculator::updateGeometry() {
 
-	const QSize em = pbAND->fontMetrics().size(0, QLatin1String("M"));
-	int margin = QApplication::style()->pixelMetric(QStyle::PM_ButtonMargin, 0, 0);
+	const QSize em = pbAND->fontMetrics().size(0, QStringLiteral("M"));
+	int margin = QApplication::style()->pixelMetric(QStyle::PM_ButtonMargin, nullptr, nullptr);
 	margin = qMax(qMin(margin / 2, 3), 3);
 
 	// left pad
@@ -719,7 +720,7 @@ void KCalculator::slotConstantToDisplay(const science_constant &const_chosen) {
 	QString val = const_chosen.value;
 	val.replace(QLatin1Char('.'), KNumber::decimalSeparator());
 	calc_display->setAmount(KNumber(val));
-    updateDisplay(0);
+    updateDisplay({});
 }
 
 //------------------------------------------------------------------------------
@@ -735,22 +736,22 @@ void KCalculator::slotBaseSelected(int base) {
 	switch (base) {
 	case BinMode:
 		current_base = calc_display->setBase(NumBase(2));
-		calc_display->setStatusText(BaseField, QLatin1String("Bin"));
+		calc_display->setStatusText(BaseField, QStringLiteral("Bin"));
 		break;
 	case OctMode:
 		current_base = calc_display->setBase(NumBase(8));
-		calc_display->setStatusText(BaseField, QLatin1String("Oct"));
+		calc_display->setStatusText(BaseField, QStringLiteral("Oct"));
 		break;
 	case DecMode:
 		current_base = calc_display->setBase(NumBase(10));
-		calc_display->setStatusText(BaseField, QLatin1String("Dec"));
+		calc_display->setStatusText(BaseField, QStringLiteral("Dec"));
 		break;
 	case HexMode:
 		current_base = calc_display->setBase(NumBase(16));
-		calc_display->setStatusText(BaseField, QLatin1String("Hex"));
+		calc_display->setStatusText(BaseField, QStringLiteral("Hex"));
 		break;
 	default:
-		calc_display->setStatusText(BaseField, QLatin1String("Error"));
+		calc_display->setStatusText(BaseField, QStringLiteral("Error"));
 		return;
 	}
 
@@ -792,7 +793,7 @@ void KCalculator::keyPressEvent(QKeyEvent *e) {
 
 	// Fix for bug #314586
 	// Basically, on some keyboards such as French, even though the decimal separator
-	// is "," the numeric keypad has a "." key. So we fake it so people can more seemlessly
+	// is "," the numeric keypad has a "." key. So we fake it so people can more seamlessly
 	// enter numbers using the keypad
     if(KNumber::decimalSeparator() != QLatin1String(".")) {
 		if(e->key() == Qt::Key_Period && e->modifiers() & Qt::KeypadModifier) {
@@ -836,13 +837,13 @@ void KCalculator::slotAngleSelected(int mode) {
 	statusBar()->setAngleMode(KCalcStatusBar::AngleMode(mode));
 	switch (mode) {
 	case DegMode:
-		calc_display->setStatusText(AngleField, QLatin1String("Deg"));
+		calc_display->setStatusText(AngleField, QStringLiteral("Deg"));
 		break;
 	case RadMode:
-		calc_display->setStatusText(AngleField, QLatin1String("Rad"));
+		calc_display->setStatusText(AngleField, QStringLiteral("Rad"));
 		break;
 	case GradMode:
-		calc_display->setStatusText(AngleField, QLatin1String("Gra"));
+		calc_display->setStatusText(AngleField, QStringLiteral("Gra"));
 		break;
 	default: // we shouldn't ever end up here
 		angle_mode_ = RadMode;
@@ -853,7 +854,7 @@ void KCalculator::slotAngleSelected(int mode) {
 
 //------------------------------------------------------------------------------
 // Name: slotEEclicked
-// Desc: starts the entering of numers using scientific notation
+// Desc: starts the entering of numbers using scientific notation
 //------------------------------------------------------------------------------
 void KCalculator::slotEEclicked() {
     calc_display->newCharacter(QLatin1Char('e'));
@@ -883,7 +884,7 @@ void KCalculator::slotShifttoggled(bool flag) {
 //------------------------------------------------------------------------------
 void KCalculator::slotHyptoggled(bool flag) {
 
-	// toggle between hyperbolic and standart trig functions
+	// toggle between hyperbolic and standard trig functions
 	hyp_mode_ = flag;
 
 	emit switchMode(ModeHyperbolic, flag);
@@ -899,7 +900,7 @@ void KCalculator::slotMemRecallclicked() {
 	calc_display->sendEvent(KCalcDisplay::EventReset);
 
 	calc_display->setAmount(memory_num_);
-	updateDisplay(0);
+    updateDisplay({});
 }
 
 //------------------------------------------------------------------------------
@@ -911,7 +912,7 @@ void KCalculator::slotMemStoreclicked() {
 	EnterEqual();
 
 	memory_num_ = calc_display->getAmount();
-	calc_display->setStatusText(MemField, QLatin1String("M"));
+	calc_display->setStatusText(MemField, QStringLiteral("M"));
 	statusBar()->setMemoryIndicator(true);
 	pbMemRecall->setEnabled(true);
 }
@@ -1069,7 +1070,7 @@ void KCalculator::slotReciclicked() {
 	KNumber tmp_num = calc_display->getAmount();
 	calc_display->sendEvent(KCalcDisplay::EventReset);
 	calc_display->setAmount(tmp_num);
-	updateDisplay(0);
+    updateDisplay({});
 }
 
 //------------------------------------------------------------------------------
@@ -1213,7 +1214,7 @@ void KCalculator::slotPowerclicked() {
 	KNumber tmp_num = calc_display->getAmount();
 	calc_display->sendEvent(KCalcDisplay::EventReset);
 	calc_display->setAmount(tmp_num);
-	updateDisplay(0);
+    updateDisplay({});
 }
 
 //------------------------------------------------------------------------------
@@ -1529,7 +1530,7 @@ void KCalculator::slotStatClearDataclicked() {
 		statusBar()->showMessage(i18n("Stat mem cleared"), 3000);
 	} else {
 		pbShift->setChecked(false);
-		updateDisplay(0);
+        updateDisplay({});
 	}
 }
 
@@ -1563,7 +1564,7 @@ void KCalculator::slotConstclicked(int button) {
 			calc_display->setAmount(calc_display->getAmount());
 		}
 
-		updateDisplay(0);
+        updateDisplay({});
 	}
 }
 
@@ -1575,29 +1576,29 @@ void KCalculator::showSettings() {
 
 	// Check if there is already a dialog and if so bring
 	// it to the foreground.
-	if (KConfigDialog::showDialog(QLatin1String("settings"))) {
+	if (KConfigDialog::showDialog(QStringLiteral("settings"))) {
 		return;
 	}
 
 	// Create a new dialog with the same name as the above checking code.
-	KConfigDialog *const dialog = new KConfigDialog(this, QLatin1String("settings"), KCalcSettings::self());
+	KConfigDialog *const dialog = new KConfigDialog(this, QStringLiteral("settings"), KCalcSettings::self());
 
 	// general settings
-	General *const general = new General(0);
+    General *const general = new General(nullptr);
 	general->kcfg_Precision->setMaximum(maxprecision);
-	dialog->addPage(general, i18n("General"), QLatin1String("accessories-calculator"), i18n("General Settings"));
+	dialog->addPage(general, i18n("General"), QStringLiteral("accessories-calculator"), i18n("General Settings"));
 
 	// font settings
-	Fonts *const fonts = new Fonts(0);
-	dialog->addPage(fonts, i18n("Font"), QLatin1String("preferences-desktop-font"), i18n("Select Display Font"));
+    Fonts *const fonts = new Fonts(nullptr);
+	dialog->addPage(fonts, i18n("Font"), QStringLiteral("preferences-desktop-font"), i18n("Select Display Font"));
 
 	// color settings
-	Colors *const color = new Colors(0);
-	dialog->addPage(color, i18n("Colors"), QLatin1String("format-fill-color"), i18n("Button & Display Colors"));
+    Colors *const color = new Colors(nullptr);
+	dialog->addPage(color, i18n("Colors"), QStringLiteral("format-fill-color"), i18n("Button & Display Colors"));
 
 	// constant settings
 	if (!constants_) {
-		constants_ = new Constants(0);
+        constants_ = new Constants(nullptr);
 	}
 
 	KCalcConstMenu *tmp_menu;
@@ -1625,7 +1626,7 @@ void KCalculator::showSettings() {
 	connect(tmp_menu, &KCalcConstMenu::triggeredConstant, this, &KCalculator::slotChooseScientificConst5);
 	constants_->pushButton5->setMenu(tmp_menu);
 
-	dialog->addPage(constants_, i18n("Constants"), QLatin1String("preferences-kcalc-constants"), i18n("Define Constants"));
+	dialog->addPage(constants_, i18n("Constants"), QStringLiteral("preferences-kcalc-constants"), i18n("Define Constants"));
 
 	// When the user clicks OK or Apply we want to update our settings.
 	connect(dialog, &KConfigDialog::settingsChanged, this, &KCalculator::updateSettings);
@@ -1720,7 +1721,7 @@ void KCalculator::slotSetSimpleMode() {
 
 	// delete the constant menu since it doesn't fit
 	delete constants_menu_;
-	constants_menu_ = 0;
+    constants_menu_ = nullptr;
 
 	KCalcSettings::setCalculatorMode(KCalcSettings::EnumCalculatorMode::simple);
 	// must be done after setting the calculator mode because the
@@ -2012,7 +2013,7 @@ void KCalculator::changeButtonNames() {
 void KCalculator::slotBitsetChanged(quint64 value) {
 
     calc_display->setAmount(KNumber(value));
-    updateDisplay(0);
+    updateDisplay({});
 }
 
 //------------------------------------------------------------------------------
@@ -2036,7 +2037,7 @@ void KCalculator::updateSettings() {
 	setPrecision();
 
 	// Show the result in the app's caption in taskbar (wishlist - bug #52858)
-	disconnect(calc_display, SIGNAL(changedText(QString)), this, 0);
+    disconnect(calc_display, SIGNAL(changedText(QString)), this, nullptr);
 
 	if (KCalcSettings::captionResult()) {
 		connect(calc_display, &KCalcDisplay::changedText, this, &KCalculator::setWindowTitle);
@@ -2085,7 +2086,7 @@ void KCalculator::setColors() {
 		return;
 	}
 
-	const QString sheet = QLatin1String("QPushButton { background-color: %1 }");
+	const QString sheet = QStringLiteral("QPushButton { background-color: %1 }");
 
 	const QColor numPal(KCalcSettings::numberButtonsColor());
 	for (int i = 0; i < 10; ++i) {
@@ -2171,7 +2172,7 @@ bool KCalculator::event(QEvent *e) {
 void KCalculator::setPrecision() {
 
 	KNumber::setDefaultFloatPrecision(KCalcSettings::precision());
-	updateDisplay(0);
+    updateDisplay({});
 }
 
 //------------------------------------------------------------------------------
@@ -2221,7 +2222,7 @@ bool KCalculator::eventFilter(QObject *o, QEvent *e) {
 
 		if (c.isValid()) {
 			QString cn = c.name();
-			QString sheet = QLatin1String("background-color: %1");
+			QString sheet = QStringLiteral("background-color: %1");
 
 			QList<QAbstractButton*> *list;
 			const int num_but = num_button_group_->buttons().indexOf(calcButton);
@@ -2280,10 +2281,10 @@ extern "C" Q_DECL_EXPORT int kdemain(int argc, char *argv[]) {
      * enable high dpi support
      */
     app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
-
-    Kdelibs4ConfigMigrator migrate(QLatin1String("kcalc"));
-    migrate.setConfigFiles(QStringList() << QLatin1String("kcalcrc"));
-    migrate.setUiFiles(QStringList() << QLatin1String("kcalcui.rc"));
+    KCrash::initialize();
+    Kdelibs4ConfigMigrator migrate(QStringLiteral("kcalc"));
+    migrate.setConfigFiles(QStringList() << QStringLiteral("kcalcrc"));
+    migrate.setUiFiles(QStringList() << QStringLiteral("kcalcui.rc"));
     migrate.migrate();
 
     KAboutData aboutData(QStringLiteral("kcalc"),
@@ -2312,7 +2313,7 @@ extern "C" Q_DECL_EXPORT int kdemain(int argc, char *argv[]) {
     aboutData.addAuthor(i18n("David Johnson"), QString(), QStringLiteral("david@usermode.org"));
 
 	KAboutData::setApplicationData(aboutData);
-	app.setWindowIcon(QIcon::fromTheme(QLatin1String("accessories-calculator"), app.windowIcon()));
+	app.setWindowIcon(QIcon::fromTheme(QStringLiteral("accessories-calculator"), app.windowIcon()));
 
 
 	QCommandLineParser parser;
